*------------- Telecommunications & Signal Processing Lab --------------
*                          McGill University
*
*
* Module:
*     SUBROUTINE VSMULN (X, A, Y, N)
*
*
* Purpose:
*     Multiply each element of a vector by a scalar value
*
*
* Description:
*     This routine multiplies each element of a vector by a given
*     value,
*       Y(i) = A*X(i)  for i from 1 to N.
*
*
* Parameters:
* R ->  X      - Input vector
* R ->  A      - Input value
* R <-  Y      - Output vector
* I ->  N      - Number of elements in each of X and Y.  N may be zero.
*
*
* Author / revision:
*     P. Kabal
*     $Revision: 1.4 $  $Date: 1995/03/08 15:05:57 $
*
*
*-----------------------------------------------------------------------

      SUBROUTINE VSMULN (X, A, Y, N)


      INTEGER N
      INTEGER I

      REAL A
      REAL X(*),Y(*)


      DO 100 I=1,N
        Y(I)=A*X(I)
 100  CONTINUE


      RETURN

      END
