*------------- Telecommunications & Signal Processing Lab --------------
*                          McGill University
*
*
* Module:
*     SUBROUTINE VZERO (X, N)
*
*
* Purpose:
*     Zero each element in a REAL array
*
*
* Description:
*     Each element of the array is zeroed.
*
*
* Parameters:
* R <-  X      - Array to be zeroed
* I ->  N      - Number of elements to be zeroed.  N can be zero.
*
*
* Author / revision:
*     P. Kabal
*     $Revision: 1.5 $  $Date: 1995/03/08 15:06:06 $
*
*
*-----------------------------------------------------------------------

      SUBROUTINE VZERO (X, N)


      INTEGER N
      INTEGER I


      REAL X(*)


      DO 100 I=1,N
        X(I)=0.0
 100  CONTINUE


      RETURN

      END
