*---------------------------INRS-Telecommunications---------------------------
*
*
* MODULE:
*		SUBROUTINE MESS (STRING)
*		FUNCTION MESS (STRING)
*
*
* PURPOSE:
*	This routine prints a message using the system message
*	facility.
*
*
* DESCRIPTION:
*	This routine prints a message.
*
*
* PARAMETERS:
* I <-	MESS   - Status return from SYS$PUTMSG
*
* C ->	STRING - Character string to be printed
*
*
* ROUTINES REQUIRED:
*	SYS$PUTMSG - System message routine
*
*
* AUTHOR / MAINTAINED BY:
*	P. Kabal
*
*
* DATE CREATED:
*	1983/08/02
*
*
* UPDATES:
*
*
*---------------------------INRS-Telecommunications---------------------------

	FUNCTION MESS (STRING)
 
 
	INTEGER FOR_I_TEXT, ARG_COUNT, FLAGS, ARG3, FAO_COUNT, SYS$PUTMSG
	PARAMETER (FOR_I_TEXT='181133'X, ARG_COUNT=3, FLAGS=1,
     -	           FAO_COUNT=1, ARG3=FAO_COUNT+65536*FLAGS)
 
 
	CHARACTER STRING*(*)
 
	INTEGER DESCRIP(2)
 
	INTEGER*4 ARG_VEC(ARG_COUNT+1) /ARG_COUNT, FOR_I_TEXT, ARG3, 0/
 
 
* Fill in the last element of the argument vector
 
	DESCRIP(1) = LEN (STRING)
	DESCRIP(2) = %LOC (STRING)
	ARG_VEC(4) = %LOC (DESCRIP)
 
 
* Print the message text without the message identifier
 
	MESS = SYS$PUTMSG (ARG_VEC, , ,)
 
 
	END
