*------------- Telecommunications & Signal Processing Lab --------------
*                          McGill University
*
*
* Module:
*     SUBROUTINE IZERO (IX, N)
*
*
* Purpose:
*     Zero an INTEGER array
*
*
* Description:
*     Each element of the given array is set to zero.
*
*
* Parameters:
* I <-  IX     - Integer array to be zeroed
* I ->  N      - Number of elements in IX.  N may be zero.
*
*
* Author / revision:
*     P. Kabal
*     $Revision: 1.4 $  $Date: 1995/03/08 15:04:44 $
*
*
*-----------------------------------------------------------------------

      SUBROUTINE IZERO (IX, N)


      INTEGER N
      INTEGER I
      INTEGER IX(*)


      DO 100 I=1,N
        IX(I)=0
 100  CONTINUE


      RETURN

      END
