*------------- Telecommunications & Signal Processing Lab --------------
*                          McGill University
*
*
* Module:
*     SUBROUTINE XYMOVE (IX, IY)
*
*
* Purpose:
*     Move the plot position
*
*
* Description:
*     This subroutine moves the pen position without drawing a line.
*
*
* Parameters:
* I ->  IX     - X coordinate of the new pen position (0 to 4095)
* I ->  IY     - Y coordinate of the new pen position (0 to 4095)
*
*
* Author / revision:
*     P. Kabal
*     $Revision: 1.4 $  $Date: 1995/03/08 15:29:11 $
*
*
*-----------------------------------------------------------------------

      SUBROUTINE XYMOVE (IX, IY)


      INTEGER IX,IY
      INTEGER IX0,IY0

* Plot device flags common area
      LOGICAL PS,TK,UN,VT
      COMMON /DEVCOM/ PS,TK,UN,VT


      CALL GETPOS(IX0,IY0)
      IF (IX.NE.IX0 .OR. IY.NE.IY0) THEN
        IF (PS) CALL PSXY(IX,IY,0)
        IF (TK) CALL TKXY(IX,IY,0)
        IF (UN) CALL UNXY(IX,IY,0)
        IF (VT) CALL VTXY(IX,IY,0)
        CALL SETPOS(IX,IY)
      END IF


      RETURN

      END
