*------------- Telecommunications & Signal Processing Lab --------------
*                          McGill University
*
*
* Module:
*     SUBROUTINE XYVECT (IX1, IY1, IX2, IY2)
*
*
* Purpose:
*     Draw a vector
*
*
* Description:
*     This subroutine draws a visible vector between the plotting
*     coordinates (IX1,IY1) and (IX2,IY2).
*
*
* Parameters:
* I ->  IX1    - X coordinate of the start of the vector (0 to 4095)
* I ->  IY1    - Y coordinate of the start of the vector (0 to 4095)
* I ->  IX2    - X coordinate of the end of the vector (0 to 4095)
* I ->  IY2    - Y coordinate of the end of the vector (0 to 4095)
*
*
* Author / revision:
*     P. Kabal
*     $Revision: 1.5 $  $Date: 1995/03/08 15:29:14 $
*
*
*-----------------------------------------------------------------------

      SUBROUTINE XYVECT (IX1, IY1, IX2, IY2)


      INTEGER IX1,IY1,IX2,IY2


      CALL XYMOVE(IX1,IY1)
      CALL XYDRAW(IX2,IY2)


      RETURN

      END
