*---------------------------INRS-Telecommunications---------------------------
*
*
* MODULE:
*	SUBROUTINE FFNAME (FNAMEI, FNAMEO)
*
*
* PURPOSE:
*	This routine returns a full file name.
*
*
* DESCRIPTION:
*	This routine takes an input file name and fills in the full
*	file specification.
*
*
* PARAMETERS:
* C ->	FNAMEI - Input character string containing the file name
* C <-	FNAMEO - Character string for the output file name
*
*
* ROUTINES REQUIRED:
*	None
*
*
* AUTHOR / MAINTAINED BY:
*	P. Kabal
*
*
* DATE CREATED:
*	1988/05/10
*
*
* UPDATES:
*
*
*---------------------------INRS-Telecommunications---------------------------

	SUBROUTINE FFNAME (FNAMEI, FNAMEO)



	CHARACTER*(*) FNAMEI,FNAMEO


* Use the INQUIRE function to fill out the file name
	INQUIRE (FILE=FNAMEI,NAME=FNAMEO)


	RETURN

	END
