*------------- Telecommunications & Signal Processing Lab --------------
*                          McGill University
*
*
* Module:
*     SUBROUTINE HALT (STRING)
*
*
* Purpose:
*     Print an error message, stop with error status set
*
*
* Description:
*     This routine prints an error message on the standard error unit
*     and then terminates execution with error code -1 (255).
*
*
* Parameters:
* C ->  STRING - Character string to be printed
*
*
* Author / revision:
*     P. Kabal
*     $Revision: 1.4 $  $Date: 1995/03/08 15:44:04 $
*
*
*-----------------------------------------------------------------------

      SUBROUTINE HALT (STRING)


      CHARACTER*(*) STRING


* Write the message text to the standard error unit and
* halt execution with a -1 (255) status code
* (Assume that the standard error unit does not use Fortran
* carriage control)
      WRITE (UNIT=0,FMT=1000) STRING
      WRITE (UNIT=0,FMT=1000) 'Fatal error - execution terminated'
      CALL EXIT(255)


      RETURN

 1000 FORMAT (A)

      END
