*---------------Bell-Northern Research / INRS Computer Laboratory-------------
*
*
* MODULE:
*	SUBROUTINE WARN (STRING)
*
*
* PURPOSE:
*	This routine prints an error message using the system
*	signalling mechanism.
*
*
* DESCRIPTION:
*	This routine prints by signalling a warning message.
*
*
* PARAMETERS:
*	STRING - Character string to be printed
*
*
* ROUTINES REQUIRED:
*	LIB$SIGNAL - Signal an error
*
*
* AUTHOR / MAINTAINED BY:
*	P. Kabal
*
*
* DATE CREATED:
*	83/05/20
*
*
* UPDATES:
*
*
*---------------Bell-Northern Research / INRS Computer Laboratory-------------

	SUBROUTINE WARN (STRING)


	INTEGER FOR_W_TEXT
	PARAMETER (FOR_W_TEXT='181130'X)

	CHARACTER STRING*(*)


* Signal the message text as a warning text
	CALL LIB$SIGNAL(%VAL(FOR_W_TEXT),%VAL(1),STRING)

	RETURN


	END
