*---------------------------INRS-Telecommunications---------------------------
*
*
* MODULE:
*	SUBROUTINE PSYMSG (ISTAT)
*
*
* PURPOSE:
*	This routine prints a system message.
*
*
* DESCRIPTION:
*	This routine prints a system message on the standard output
*	device.
*
*
* PARAMETERS:
*	ISTAT  - VMS status code
*
*
* ROUTINES REQUIRED:
*	LIB$PUT_OUTPUT - System routine to print an error message
*	LIB$SYS_GETMSG - System routine to get error message text
*
*
* AUTHOR / MAINTAINED BY:
*	P. Kabal
*
*
* DATE CREATED:
*	88/08/10
*
*
* UPDATES:
*
*
*---------------------------INRS-Telecommunications---------------------------

	SUBROUTINE PSYMSG (ISTAT)


	INTEGER*2 MSGFMT
	PARAMETER (MSGFMT=15)

	CHARACTER*256 STRING



	CALL LIB$SYS_GETMSG(ISTAT,NC,STRING,MSGFMT,)
	CALL LIB$PUT_OUTPUT(STRING(1:NC))

	RETURN

	END
