*------------- Telecommunications & Signal Processing Lab --------------
*                          McGill University
*
*
* Module:
*     SUBROUTINE VEXP10 (X, Y, N)
*
*
* Purpose:
*     Exponent (base 10) of each element of a vector
*
*
* Description:
*     This routine converts each element of the input vector to an
*     exponent (base 10) value.
*
*       y(i) =  10**x(i)  for i from 1 to N.
*
*
* Parameters:
* R ->  X      - Input vector
* R <-  Y      - Output vector (the output vector may be the same as
*                the input vector)
* I ->  N      - Number of elements in each of X and Y.  N may be zero.
*
*
* Author / revision:
*     P. Kabal
*     $Revision: 1.4 $  $Date: 1995/03/08 15:05:22 $
*
*
*-----------------------------------------------------------------------

      SUBROUTINE VEXP10 (X, Y, N)


      INTEGER N
      INTEGER I

      REAL X(*),Y(*)


      DO 100 I=1,N
        Y(I)=10.**X(I)
 100  CONTINUE


      RETURN

      END
