*------------- Telecommunications & Signal Processing Lab --------------
*                          McGill University
*
*
* Module:
*     SUBROUTINE ICOPY (IX, IY, N)
*
*
* Purpose:
*     Copy an INTEGER array
*
*
* Description:
*     The elements of the input array are transferred to the output
*     array starting at the bottom.  If N is zero, no transfer is
*     performed.
*
*
* Parameters:
* I ->  IX     - Input array
* I <-  IY     - Output array
* I ->  N      - Number of elements to be transferred
*
*
* Author / revision:
*     P. Kabal
*     $Revision: 1.4 $  $Date: 1995/03/08 15:04:36 $
*
*
*-----------------------------------------------------------------------

      SUBROUTINE ICOPY (IX, IY, N)


      INTEGER N
      INTEGER I
      INTEGER IX(*),IY(*)


      DO 100 I=1,N
        IY(I)=IX(I)
 100  CONTINUE


      RETURN

      END
