*------------- Telecommunications & Signal Processing Lab --------------
*                          McGill University
*
*
* Module:
*     SUBROUTINE PLEND
*
*
* Purpose:
*     Terminate a plot
*
*
* Description:
*     This subroutine terminates a plot initiated with the subroutine
*     PLINIT.
*
*
* Parameters:
*     None
*
*
* Author / revision:
*     P. Kabal
*     $Revision: 1.4 $  $Date: 1995/03/08 15:28:12 $
*
*
*-----------------------------------------------------------------------

      SUBROUTINE PLEND


* Plot device flags common area
      LOGICAL PS,TK,UN,VT
      COMMON /DEVCOM/ PS,TK,UN,VT


* Terminate plotting
      IF (PS) THEN
        CALL PSEND
        PS=.FALSE.
      END IF
      IF (TK) THEN
        CALL TKEND
        TK=.FALSE.
      END IF
      IF (UN) THEN
        CALL UNEND
        UN=.FALSE.
      END IF
      IF (VT) THEN
        CALL VTEND
        VT=.FALSE.
      END IF


      RETURN

      END
