*------------- Telecommunications & Signal Processing Lab --------------
*                          McGill University
*
*
* Module:
*     SUBROUTINE WARN (STRING)
*
*
* Purpose:
*     Print a warning message on the standard error unit
*
*
* Description:
*     This routine prints on the standard error unit.
*
*
* Parameters:
* C ->  STRING - Character string to be printed
*
*
* Author / revision:
*     P. Kabal
*     $Revision: 1.4 $  $Date: 1995/03/08 15:44:15 $
*
*
*-----------------------------------------------------------------------

      SUBROUTINE WARN (STRING)


      CHARACTER*(*) STRING


* Print the message text to the standard error unit
* (Assume that the standard error unit does not use Fortran
* carriage control)
      WRITE (UNIT=0,FMT=1000) STRING


      RETURN

 1000 FORMAT (A)

      END
